class Morse < Formula
  desc "QSO generator and morse code trainer"
  homepage "http://www.catb.org/~esr/morse/"
  # reported the artifact issue on the project page, https://gitlab.com/esr/morse-classic/-/issues/1
  url "https://gitlab.com/esr/morse-classic/-/archive/2.6/morse-classic-2.6.tar.bz2"
  sha256 "ec44144d52a1eef36fbe0ca400c54556a7ba8f8c3de38d80512d19703b89f615"
  license "BSD-2-Clause"

  livecheck do
    url :homepage
    regex(/href=.*?morse[._-]v?(\d+(?:\.\d+)+)\.t/i)
  end

  depends_on "pkg-config" => :build
  depends_on "xmlto" => :build
  depends_on "pulseaudio"

  patch :DATA

  def install
    ENV["XML_CATALOG_FILES"] = "#{etc}/xml/catalog"

    ENV["CC"] = "#{ENV.cc} -Wno-implicit-function-declaration" if DevelopmentTools.clang_build_version >= 1403

    system "make", "all"
    bin.install %w[morse QSO]
    man1.install %w[morse.1 QSO.1]
  end

  test do
    # Fails in Linux CI with "pa_simple_Write failed"
    return if OS.linux? && ENV["HOMEBREW_GITHUB_ACTIONS"]

    assert_match "Could not initialize audio", shell_output("#{bin}/morse -- 2>&1", 1)
  end
end

__END__
diff --git a/Makefile b/Makefile
index 8bdf1f6..df39baa 100644
--- a/Makefile
+++ b/Makefile
@@ -28,8 +28,8 @@
 #DEVICE = X11
 #DEVICE = Linux
 #DEVICE = OSS
-DEVICE = ALSA
-#DEVICE = PA
+#DEVICE = ALSA
+DEVICE = PA

 VERSION=$(shell sed -n <NEWS '/^[0-9]/s/:.*//p' | head -1)
